#!/bin/sh

# Start a local SCALLA cluster with a redirector on 1094 and two dataservs on 11094 and 21094
# and related 'cmsd' daemons

WRKDIR="/tmp/testxrd"
rm -fr $WRKDIR
mkdir -p "$WRKDIR/log"
mkdir -p "$WRKDIR/one/log"
mkdir -p "$WRKDIR/two/log"
mkdir -p "$WRKDIR/one/pool"
mkdir -p "$WRKDIR/two/pool"

LOCALHOST=`hostname`

# Create the config files
mkdir -p "$WRKDIR/config"
CFGR="$WRKDIR/xrd.cf"
CFGO="$WRKDIR/one/xrd.cf"
CFGT="$WRKDIR/two/xrd.cf"
#
# Redirector
cat > $CFGR << EOF
#
# Main port
if exec xrootd
  xrd.port 1094
fi
#
# Admin paths
all.adminpath $WRKDIR/admin
#
# Export
all.export /pool
#
# OpenFS section
xrootd.fslib libXrdOfs.so
ofs.forward all
#
# Clustering
cms.allow host *
all.manager $LOCALHOST 3121
all.role manager

# Client selection for new files
cms.space 1g 2g

EOF
#
# DataServer One
cat > $CFGO << EOF
#
# Main port
if exec xrootd
  xrd.port 11094
fi
#
# Admin paths
all.adminpath $WRKDIR/one/admin
#
# Export
all.export /pool
oss.localroot $WRKDIR/one
#
# OpenFS section
xrootd.fslib libXrdOfs.so
#
# Clustering
cms.allow host *
all.manager $LOCALHOST 3121
all.role server

# Client selection for new files
cms.space 1g 2g

EOF
#
# DataServer Two
cat > $CFGT << EOF
#
# Main port
if exec xrootd
  xrd.port 21094
fi
#
# Admin paths
all.adminpath $WRKDIR/two/admin
#
# Export
all.export /pool
oss.localroot $WRKDIR/two
#
# OpenFS section
xrootd.fslib libXrdOfs.so
#
# Clustering
cms.allow host *
all.manager $LOCALHOST 3121
all.role server

# Client selection for new files
cms.space 1g 2g

EOF
#
# Start the daemons now: redirectors
xrootd -b -l $WRKDIR/log/xrootd.log -d -c $CFGR
cmsd -b -l $WRKDIR/log/cmsd.log -d -c $CFGR
# dataserver one
xrootd -b -l $WRKDIR/one/log/xrootd.log -d -c $CFGO
cmsd -b -l $WRKDIR/one/log/cmsd.log -d -c $CFGO
# dataserver two
xrootd -b -l $WRKDIR/two/log/xrootd.log -d -c $CFGT
cmsd -b -l $WRKDIR/two/log/cmsd.log -d -c $CFGT
#
# Done
echo "Done!"

